package v1

// This file contains methods that can be used by the go-restful package to generate Swagger
// documentation for the object types found in 'types.go' This file is automatically generated
// by hack/update-generated-swagger-descriptions.sh and should be run after a full build of OpenShift.
// ==== DO NOT EDIT THIS FILE MANUALLY ====

var map_BinaryBuildRequestOptions = map[string]string{
	"":                        "BinaryBuildRequestOptions are the options required to fully speficy a binary build request",
	"metadata":                "Standard object's metadata.",
	"asFile":                  "AsFile determines if the binary should be created as a file within the source rather than extracted as an archive",
	"revision.commit":         "Commit is the value identifying a specific commit",
	"revision.message":        "Message is the description of a specific commit",
	"revision.authorName":     "AuthorName of the source control user",
	"revision.authorEmail":    "AuthorEmail of the source control user",
	"revision.committerName":  "CommitterName of the source control user",
	"revision.committerEmail": "CommitterEmail of the source control user",
}

func (BinaryBuildRequestOptions) SwaggerDoc() map[string]string {
	return map_BinaryBuildRequestOptions
}

var map_BinaryBuildSource = map[string]string{
	"":       "BinaryBuildSource describes a binary file to be used for the Docker and Source build strategies, where the file will be extracted and used as the build source.",
	"asFile": "AsFile indicates that the provided binary input should be considered a single file within the build input. For example, specifying \"webapp.war\" would place the provided binary as `/webapp.war` for the builder. If left empty, the Docker and Source build strategies assume this file is a zip, tar, or tar.gz file and extract it as the source. The custom strategy receives this binary as standard input. This filename may not contain slashes or be '..' or '.'.",
}

func (BinaryBuildSource) SwaggerDoc() map[string]string {
	return map_BinaryBuildSource
}

var map_Build = map[string]string{
	"":         "Build encapsulates the inputs needed to produce a new deployable image, as well as the status of the execution and a reference to the Pod which executed the build.",
	"metadata": "Standard object's metadata.",
	"spec":     "Spec is all the inputs used to execute the build.",
	"status":   "Status is the current status of the build.",
}

func (Build) SwaggerDoc() map[string]string {
	return map_Build
}

var map_BuildConfig = map[string]string{
	"":         "BuildConfig is a template which can be used to create new builds.",
	"metadata": "Standard object's metadata.",
	"spec":     "Spec holds all the input necessary to produce a new build, and the conditions when to trigger them.",
	"status":   "Status holds any relevant information about a build config",
}

func (BuildConfig) SwaggerDoc() map[string]string {
	return map_BuildConfig
}

var map_BuildConfigList = map[string]string{
	"":         "BuildConfigList is a collection of BuildConfigs.",
	"metadata": "Standard object's metadata.",
	"items":    "Items is a list of build configs",
}

func (BuildConfigList) SwaggerDoc() map[string]string {
	return map_BuildConfigList
}

var map_BuildConfigSpec = map[string]string{
	"":         "BuildConfigSpec describes when and how builds are created",
	"triggers": "Triggers determine how new Builds can be launched from a BuildConfig. If no triggers are defined, a new build can only occur as a result of an explicit client build creation.",
}

func (BuildConfigSpec) SwaggerDoc() map[string]string {
	return map_BuildConfigSpec
}

var map_BuildConfigStatus = map[string]string{
	"":            "BuildConfigStatus contains current state of the build config object.",
	"lastVersion": "LastVersion is used to inform about number of last triggered build.",
}

func (BuildConfigStatus) SwaggerDoc() map[string]string {
	return map_BuildConfigStatus
}

var map_BuildList = map[string]string{
	"":         "BuildList is a collection of Builds.",
	"metadata": "Standard object's metadata.",
	"items":    "Items is a list of builds",
}

func (BuildList) SwaggerDoc() map[string]string {
	return map_BuildList
}

var map_BuildLog = map[string]string{
	"": "BuildLog is the (unused) resource associated with the build log redirector",
}

func (BuildLog) SwaggerDoc() map[string]string {
	return map_BuildLog
}

var map_BuildLogOptions = map[string]string{
	"":             "BuildLogOptions is the REST options for a build log",
	"container":    "The container for which to stream logs. Defaults to only container if there is one container in the pod.",
	"follow":       "Follow if true indicates that the build log should be streamed until the build terminates.",
	"previous":     "Return previous build logs. Defaults to false.",
	"sinceSeconds": "A relative time in seconds before the current time from which to show logs. If this value precedes the time a pod was started, only logs since the pod start will be returned. If this value is in the future, no logs will be returned. Only one of sinceSeconds or sinceTime may be specified.",
	"sinceTime":    "An RFC3339 timestamp from which to show logs. If this value preceeds the time a pod was started, only logs since the pod start will be returned. If this value is in the future, no logs will be returned. Only one of sinceSeconds or sinceTime may be specified.",
	"timestamps":   "If true, add an RFC3339 or RFC3339Nano timestamp at the beginning of every line of log output. Defaults to false.",
	"tailLines":    "If set, the number of lines from the end of the logs to show. If not specified, logs are shown from the creation of the container or sinceSeconds or sinceTime",
	"limitBytes":   "If set, the number of bytes to read from the server before terminating the log output. This may not display a complete final line of logging, and may return slightly more or slightly less than the specified limit.",
	"nowait":       "NoWait if true causes the call to return immediately even if the build is not available yet. Otherwise the server will wait until the build has started.",
	"version":      "Version of the build for which to view logs.",
}

func (BuildLogOptions) SwaggerDoc() map[string]string {
	return map_BuildLogOptions
}

var map_BuildOutput = map[string]string{
	"":           "BuildOutput is input to a build strategy and describes the Docker image that the strategy should produce.",
	"to":         "To defines an optional location to push the output of this build to. Kind must be one of 'ImageStreamTag' or 'DockerImage'. This value will be used to look up a Docker image repository to push to. In the case of an ImageStreamTag, the ImageStreamTag will be looked for in the namespace of the build unless Namespace is specified.",
	"pushSecret": "PushSecret is the name of a Secret that would be used for setting up the authentication for executing the Docker push to authentication enabled Docker Registry (or Docker Hub).",
}

func (BuildOutput) SwaggerDoc() map[string]string {
	return map_BuildOutput
}

var map_BuildPostCommitSpec = map[string]string{
	"":        "A BuildPostCommitSpec holds a build post commit hook specification. The hook executes a command in a temporary container running the build output image, immediately after the last layer of the image is committed and before the image is pushed to a registry. The command is executed with the current working directory ($PWD) set to the image's WORKDIR.\n\nThe build will be marked as failed if the hook execution fails. It will fail if the script or command return a non-zero exit code, or if there is any other error related to starting the temporary container.\n\nThere are five different ways to configure the hook. As an example, all forms below are equivalent and will execute `rake test --verbose`.\n\n1. Shell script:\n\n       \"postCommit\": {\n         \"script\": \"rake test --verbose\",\n       }\n\n    The above is a convenient form which is equivalent to:\n\n       \"postCommit\": {\n         \"command\": [\"/bin/sh\", \"-ic\"],\n         \"args\":    [\"rake test --verbose\"]\n       }\n\n2. A command as the image entrypoint:\n\n       \"postCommit\": {\n         \"commit\": [\"rake\", \"test\", \"--verbose\"]\n       }\n\n    Command overrides the image entrypoint in the exec form, as documented in\n    Docker: https://docs.docker.com/engine/reference/builder/#entrypoint.\n\n3. Pass arguments to the default entrypoint:\n\n       \"postCommit\": {\n\t\t      \"args\": [\"rake\", \"test\", \"--verbose\"]\n\t      }\n\n    This form is only useful if the image entrypoint can handle arguments.\n\n4. Shell script with arguments:\n\n       \"postCommit\": {\n         \"script\": \"rake test $1\",\n         \"args\":   [\"--verbose\"]\n       }\n\n    This form is useful if you need to pass arguments that would otherwise be\n    hard to quote properly in the shell script. In the script, $0 will be\n    \"/bin/sh\" and $1, $2, etc, are the positional arguments from Args.\n\n5. Command with arguments:\n\n       \"postCommit\": {\n         \"command\": [\"rake\", \"test\"],\n         \"args\":    [\"--verbose\"]\n       }\n\n    This form is equivalent to appending the arguments to the Command slice.\n\nIt is invalid to provide both Script and Command simultaneously. If none of the fields are specified, the hook is not executed.",
	"command": "Command is the command to run. It may not be specified with Script. This might be needed if the image doesn't have `/bin/sh`, or if you do not want to use a shell. In all other cases, using Script might be more convenient.",
	"args":    "Args is a list of arguments that are provided to either Command, Script or the Docker image's default entrypoint. The arguments are placed immediately after the command to be run.",
	"script":  "Script is a shell script to be run with `/bin/sh -ic`. It may not be specified with Command. Use Script when a shell script is appropriate to execute the post build hook, for example for running unit tests with `rake test`. If you need control over the image entrypoint, or if the image does not have `/bin/sh`, use Command and/or Args. The `-i` flag is needed to support CentOS and RHEL images that use Software Collections (SCL), in order to have the appropriate collections enabled in the shell. E.g., in the Ruby image, this is necessary to make `ruby`, `bundle` and other binaries available in the PATH.",
}

func (BuildPostCommitSpec) SwaggerDoc() map[string]string {
	return map_BuildPostCommitSpec
}

var map_BuildRequest = map[string]string{
	"":                 "BuildRequest is the resource used to pass parameters to build generator",
	"metadata":         "Standard object's metadata.",
	"revision":         "Revision is the information from the source for a specific repo snapshot.",
	"triggeredByImage": "TriggeredByImage is the Image that triggered this build.",
	"from":             "From is the reference to the ImageStreamTag that triggered the build.",
	"binary":           "Binary indicates a request to build from a binary provided to the builder",
	"lastVersion":      "LastVersion (optional) is the LastVersion of the BuildConfig that was used to generate the build. If the BuildConfig in the generator doesn't match, a build will not be generated.",
	"env":              "Env contains additional environment variables you want to pass into a builder container",
}

func (BuildRequest) SwaggerDoc() map[string]string {
	return map_BuildRequest
}

var map_BuildSource = map[string]string{
	"":             "BuildSource is the SCM used for the build.",
	"type":         "Type of build input to accept",
	"binary":       "Binary builds accept a binary as their input. The binary is generally assumed to be a tar, gzipped tar, or zip file depending on the strategy. For Docker builds, this is the build context and an optional Dockerfile may be specified to override any Dockerfile in the build context. For Source builds, this is assumed to be an archive as described above. For Source and Docker builds, if binary.asFile is set the build will receive a directory with a single file. contextDir may be used when an archive is provided. Custom builds will receive this binary as input on STDIN.",
	"dockerfile":   "Dockerfile is the raw contents of a Dockerfile which should be built. When this option is specified, the FROM may be modified based on your strategy base image and additional ENV stanzas from your strategy environment will be added after the FROM, but before the rest of your Dockerfile stanzas. The Dockerfile source type may be used with other options like git - in those cases the Git repo will have any innate Dockerfile replaced in the context dir.",
	"git":          "Git contains optional information about git build source",
	"images":       "Images describes a set of images to be used to provide source for the build",
	"contextDir":   "ContextDir specifies the sub-directory where the source code for the application exists. This allows to have buildable sources in directory other than root of repository.",
	"sourceSecret": "SourceSecret is the name of a Secret that would be used for setting up the authentication for cloning private repository. The secret contains valid credentials for remote repository, where the data's key represent the authentication method to be used and value is the base64 encoded credentials. Supported auth methods are: ssh-privatekey.",
	"secrets":      "Secrets represents a list of secrets and their destinations that will be used only for the build.",
}

func (BuildSource) SwaggerDoc() map[string]string {
	return map_BuildSource
}

var map_BuildSpec = map[string]string{
	"":                          "BuildSpec encapsulates all the inputs necessary to represent a build.",
	"serviceAccount":            "ServiceAccount is the name of the ServiceAccount to use to run the pod created by this build. The pod will be allowed to use secrets referenced by the ServiceAccount",
	"source":                    "Source describes the SCM in use.",
	"revision":                  "Revision is the information from the source for a specific repo snapshot. This is optional.",
	"strategy":                  "Strategy defines how to perform a build.",
	"output":                    "Output describes the Docker image the Strategy should produce.",
	"resources":                 "Compute resource requirements to execute the build",
	"postCommit":                "PostCommit is a build hook executed after the build output image is committed, before it is pushed to a registry.",
	"completionDeadlineSeconds": "Optional duration in seconds, counted from the time when a build pod gets scheduled in the system, that the build may be active on a node before the system actively tries to terminate the build; value must be positive integer",
}

func (BuildSpec) SwaggerDoc() map[string]string {
	return map_BuildSpec
}

var map_BuildStatus = map[string]string{
	"":                           "BuildStatus contains the status of a build",
	"phase":                      "Phase is the point in the build lifecycle.",
	"cancelled":                  "Cancelled describes if a cancel event was triggered for the build.",
	"reason":                     "Reason is a brief CamelCase string that describes any failure and is meant for machine parsing and tidy display in the CLI.",
	"message":                    "Message is a human-readable message indicating details about why the build has this status.",
	"startTimestamp":             "StartTimestamp is a timestamp representing the server time when this Build started running in a Pod. It is represented in RFC3339 form and is in UTC.",
	"completionTimestamp":        "CompletionTimestamp is a timestamp representing the server time when this Build was finished, whether that build failed or succeeded.  It reflects the time at which the Pod running the Build terminated. It is represented in RFC3339 form and is in UTC.",
	"duration":                   "Duration contains time.Duration object describing build time.",
	"outputDockerImageReference": "OutputDockerImageReference contains a reference to the Docker image that will be built by this build. Its value is computed from Build.Spec.Output.To, and should include the registry address, so that it can be used to push and pull the image.",
	"config":                     "Config is an ObjectReference to the BuildConfig this Build is based on.",
}

func (BuildStatus) SwaggerDoc() map[string]string {
	return map_BuildStatus
}

var map_BuildStrategy = map[string]string{
	"":               "BuildStrategy contains the details of how to perform a build.",
	"type":           "Type is the kind of build strategy.",
	"dockerStrategy": "DockerStrategy holds the parameters to the Docker build strategy.",
	"sourceStrategy": "SourceStrategy holds the parameters to the Source build strategy.",
	"customStrategy": "CustomStrategy holds the parameters to the Custom build strategy",
}

func (BuildStrategy) SwaggerDoc() map[string]string {
	return map_BuildStrategy
}

var map_BuildTriggerPolicy = map[string]string{
	"":            "BuildTriggerPolicy describes a policy for a single trigger that results in a new Build.",
	"type":        "Type is the type of build trigger",
	"github":      "GitHubWebHook contains the parameters for a GitHub webhook type of trigger",
	"generic":     "GenericWebHook contains the parameters for a Generic webhook type of trigger",
	"imageChange": "ImageChange contains parameters for an ImageChange type of trigger",
}

func (BuildTriggerPolicy) SwaggerDoc() map[string]string {
	return map_BuildTriggerPolicy
}

var map_CustomBuildStrategy = map[string]string{
	"":                   "CustomBuildStrategy defines input parameters specific to Custom build.",
	"from":               "From is reference to an DockerImage, ImageStreamTag, or ImageStreamImage from which the docker image should be pulled",
	"pullSecret":         "PullSecret is the name of a Secret that would be used for setting up the authentication for pulling the Docker images from the private Docker registries",
	"env":                "Env contains additional environment variables you want to pass into a builder container",
	"exposeDockerSocket": "ExposeDockerSocket will allow running Docker commands (and build Docker images) from inside the Docker container.",
	"forcePull":          "ForcePull describes if the controller should configure the build pod to always pull the images for the builder or only pull if it is not present locally",
	"secrets":            "Secrets is a list of additional secrets that will be included in the build pod",
	"buildAPIVersion":    "BuildAPIVersion is the requested API version for the Build object serialized and passed to the custom builder",
}

func (CustomBuildStrategy) SwaggerDoc() map[string]string {
	return map_CustomBuildStrategy
}

var map_DockerBuildStrategy = map[string]string{
	"":               "DockerBuildStrategy defines input parameters specific to Docker build.",
	"from":           "From is reference to an DockerImage, ImageStreamTag, or ImageStreamImage from which the docker image should be pulled the resulting image will be used in the FROM line of the Dockerfile for this build.",
	"pullSecret":     "PullSecret is the name of a Secret that would be used for setting up the authentication for pulling the Docker images from the private Docker registries",
	"noCache":        "NoCache if set to true indicates that the docker build must be executed with the --no-cache=true flag",
	"env":            "Env contains additional environment variables you want to pass into a builder container",
	"forcePull":      "ForcePull describes if the builder should pull the images from registry prior to building.",
	"dockerfilePath": "DockerfilePath is the path of the Dockerfile that will be used to build the Docker image, relative to the root of the context (contextDir).",
}

func (DockerBuildStrategy) SwaggerDoc() map[string]string {
	return map_DockerBuildStrategy
}

var map_GenericWebHookEvent = map[string]string{
	"":     "GenericWebHookEvent is the payload expected for a generic webhook post",
	"type": "Type is the type of source repository",
	"git":  "Git is the git information if the Type is BuildSourceGit",
}

func (GenericWebHookEvent) SwaggerDoc() map[string]string {
	return map_GenericWebHookEvent
}

var map_GitBuildSource = map[string]string{
	"":           "GitBuildSource defines the parameters of a Git SCM",
	"uri":        "URI points to the source that will be built. The structure of the source will depend on the type of build to run",
	"ref":        "Ref is the branch/tag/ref to build.",
	"httpProxy":  "HTTPProxy is a proxy used to reach the git repository over http",
	"httpsProxy": "HTTPSProxy is a proxy used to reach the git repository over https",
}

func (GitBuildSource) SwaggerDoc() map[string]string {
	return map_GitBuildSource
}

var map_GitInfo = map[string]string{
	"": "GitInfo is the aggregated git information for a generic webhook post",
}

func (GitInfo) SwaggerDoc() map[string]string {
	return map_GitInfo
}

var map_GitSourceRevision = map[string]string{
	"":          "GitSourceRevision is the commit information from a git source for a build",
	"commit":    "Commit is the commit hash identifying a specific commit",
	"author":    "Author is the author of a specific commit",
	"committer": "Committer is the committer of a specific commit",
	"message":   "Message is the description of a specific commit",
}

func (GitSourceRevision) SwaggerDoc() map[string]string {
	return map_GitSourceRevision
}

var map_ImageChangeTrigger = map[string]string{
	"": "ImageChangeTrigger allows builds to be triggered when an ImageStream changes",
	"lastTriggeredImageID": "LastTriggeredImageID is used internally by the ImageChangeController to save last used image ID for build",
	"from":                 "From is a reference to an ImageStreamTag that will trigger a build when updated It is optional. If no From is specified, the From image from the build strategy will be used. Only one ImageChangeTrigger with an empty From reference is allowed in a build configuration.",
}

func (ImageChangeTrigger) SwaggerDoc() map[string]string {
	return map_ImageChangeTrigger
}

var map_ImageSource = map[string]string{
	"":           "ImageSource describes an image that is used as source for the build",
	"from":       "From is a reference to an ImageStreamTag, ImageStreamImage, or DockerImage to copy source from.",
	"paths":      "Paths is a list of source and destination paths to copy from the image.",
	"pullSecret": "PullSecret is a reference to a secret to be used to pull the image from a registry If the image is pulled from the OpenShift registry, this field does not need to be set.",
}

func (ImageSource) SwaggerDoc() map[string]string {
	return map_ImageSource
}

var map_ImageSourcePath = map[string]string{
	"":               "ImageSourcePath describes a path to be copied from a source image and its destination within the build directory.",
	"sourcePath":     "SourcePath is the absolute path of the file or directory inside the image to copy to the build directory.",
	"destinationDir": "DestinationDir is the relative directory within the build directory where files copied from the image are placed.",
}

func (ImageSourcePath) SwaggerDoc() map[string]string {
	return map_ImageSourcePath
}

var map_SecretBuildSource = map[string]string{
	"":               "SecretBuildSource describes a secret and its destination directory that will be used only at the build time. The content of the secret referenced here will be copied into the destination directory instead of mounting.",
	"secret":         "Secret is a reference to an existing secret that you want to use in your build.",
	"destinationDir": "DestinationDir is the directory where the files from the secret should be available for the build time. For the Source build strategy, these will be injected into a container where the assemble script runs. Later, when the script finishes, all files injected will be truncated to zero length. For the Docker build strategy, these will be copied into the build directory, where the Dockerfile is located, so users can ADD or COPY them during docker build.",
}

func (SecretBuildSource) SwaggerDoc() map[string]string {
	return map_SecretBuildSource
}

var map_SecretSpec = map[string]string{
	"":             "SecretSpec specifies a secret to be included in a build pod and its corresponding mount point",
	"secretSource": "SecretSource is a reference to the secret",
	"mountPath":    "MountPath is the path at which to mount the secret",
}

func (SecretSpec) SwaggerDoc() map[string]string {
	return map_SecretSpec
}

var map_SourceBuildStrategy = map[string]string{
	"":            "SourceBuildStrategy defines input parameters specific to an Source build.",
	"from":        "From is reference to an DockerImage, ImageStreamTag, or ImageStreamImage from which the docker image should be pulled",
	"pullSecret":  "PullSecret is the name of a Secret that would be used for setting up the authentication for pulling the Docker images from the private Docker registries",
	"env":         "Env contains additional environment variables you want to pass into a builder container",
	"scripts":     "Scripts is the location of Source scripts",
	"incremental": "Incremental flag forces the Source build to do incremental builds if true.",
	"forcePull":   "ForcePull describes if the builder should pull the images from registry prior to building.",
}

func (SourceBuildStrategy) SwaggerDoc() map[string]string {
	return map_SourceBuildStrategy
}

var map_SourceControlUser = map[string]string{
	"":      "SourceControlUser defines the identity of a user of source control",
	"name":  "Name of the source control user",
	"email": "Email of the source control user",
}

func (SourceControlUser) SwaggerDoc() map[string]string {
	return map_SourceControlUser
}

var map_SourceRevision = map[string]string{
	"":     "SourceRevision is the revision or commit information from the source for the build",
	"type": "Type of the build source",
	"git":  "Git contains information about git-based build source",
}

func (SourceRevision) SwaggerDoc() map[string]string {
	return map_SourceRevision
}

var map_WebHookTrigger = map[string]string{
	"":       "WebHookTrigger is a trigger that gets invoked using a webhook type of post",
	"secret": "Secret used to validate requests.",
}

func (WebHookTrigger) SwaggerDoc() map[string]string {
	return map_WebHookTrigger
}
